@@ -259,10 +259,6 @@ class Environment(object):
             cfg_opts = self._config_reader(context['config'])
             context.update(cfg_opts)
         
-        # write config if user supplies method
-        if self._config_writer is not None:    
-            self._config_writer(context)
-        
         self._options = context
         LOGGER.setLevel(context['logging_level'])
         
@@ -284,6 +280,10 @@ class Environment(object):
     
         used_cpus = min([num_cpus, max_cpus])
     
+        # write config if user supplies method
+        if self._config_writer is not None:
+            self._config_writer(**context)
+        
         # Create output directory if it doesn't exist
         for item in sequence:
             item.check_output_dir(item.output_dir)
@@ -397,7 +397,6 @@ class FilenameParser(object):
             else:
                 output_dir = os.path.join(target_dir, input_dir)
         self.output_dir = output_dir
-        self.check_output_dir(output_dir)
         debug('Using %s as output_dir', self.output_dir)
 
         self.protoname = os.path.splitext(
